@@ -35,7 +35,7 @@ fn create_env() -> *mut OrtEnv {
     // panic when failed to create env
     check_status(status).expect("Failed to create inference environment");
 
-    return env_ptr;
+    env_ptr
 }
 
 pub(crate) fn get_env_ptr() -> *mut OrtEnv {
@@ -45,14 +45,29 @@ pub(crate) fn get_env_ptr() -> *mut OrtEnv {
 
 #[cfg(test)]
 mod test {
+    use std::path::Path;
+
     use tracing_test::traced_test;
 
+    use crate::api::initialize_runtime;
+
     use super::*;
 
     #[test]
     #[traced_test]
     fn test_env() {
+        setup_runtime();
         let p = get_env_ptr();
         assert_ne!(p, null_mut());
     }
+
+    fn setup_runtime() {
+        #[cfg(target_os = "windows")]
+        let path = "D:\\Projects\\Rust\\ors\\onnxruntime.dll";
+        #[cfg(target_os = "macos")]
+        let path = "/usr/local/lib/libonnxruntime.1.8.1.dylib";
+        #[cfg(target_os = "linux")]
+        let path = "/usr/local/lib/libonnxruntime.so";
+        initialize_runtime(Path::new(path)).unwrap();
+    }
 }
