@@ -27,7 +27,7 @@ pub struct Session {
     output_info: Vec<SessionOutputInfo>,
 }
 
-pub fn run(session: &mut Session, inputs: &Vec<Tensor>, outputs: &mut Vec<Tensor>) -> Result<()> {
+pub fn run(session: &mut Session, inputs: &[Tensor], outputs: &mut Vec<Tensor>) -> Result<()> {
     let input_names_ptr: Vec<*const i8> = session
         .input_info
         .iter()
@@ -238,7 +238,7 @@ pub(crate) fn get_default_allocator() -> Result<*mut OrtAllocator> {
 
 pub(crate) fn get_default_memory_info() -> Result<*mut OrtMemoryInfo> {
     let allocator = get_default_allocator()?;
-    return get_allocator_mem_info(allocator);
+    get_allocator_mem_info(allocator)
 }
 
 pub(crate) fn get_allocator_mem_info(allocator: *const OrtAllocator) -> Result<*mut OrtMemoryInfo> {
@@ -253,13 +253,15 @@ mod test {
     use std::time::SystemTime;
 
     use super::*;
-    use crate::tensor::create_tensor_with_ndarray;
+    use crate::{api::initialize_runtime, tensor::create_tensor_with_ndarray};
     use ndarray::{ArrayD, IxDyn};
+    use tracing::debug;
     use tracing_test::traced_test;
 
     #[test]
     #[traced_test]
     fn test_session_run() {
+        setup_runtime();
         let session_builder = SessionBuilder::new().unwrap();
         let mut session = session_builder
             .graph_optimization_level(SessionGraphOptimizationLevel::All)
@@ -320,8 +322,8 @@ mod test {
         let inference_1_start = SystemTime::now();
         run(&mut session, &inputs, &mut outputs).unwrap();
 
-        println!("inference result: logits: {:?}", outputs[0].data);
-        println!(
+        debug!("inference result: logits: {:?}", outputs[0].data);
+        debug!(
             "inference costs: {:?}",
             SystemTime::now().duration_since(inference_1_start)
         );
@@ -330,6 +332,7 @@ mod test {
     #[test]
     #[traced_test]
     fn test_create_session() {
+        setup_runtime();
         let session_builder = SessionBuilder::new().unwrap();
         let session = session_builder
             .intra_number_threads(4)
@@ -346,14 +349,13 @@ mod test {
             .unwrap();
 
         println!("{:#?}", session);
-        println!("{:#?}", session.input_info);
-        println!("{:#?}", session.output_info);
         assert_ne!(session.session_ptr, null_mut());
     }
 
     #[test]
     #[traced_test]
     fn test_session_drop() {
+        setup_runtime();
         {
             let session_builder = SessionBuilder::new().unwrap();
             let session = session_builder
@@ -373,6 +375,16 @@ mod test {
         let path = "D:\\Projects\\Rust\\ors\\gpt2.onnx";
         #[cfg(not(target_family = "windows"))]
         let path = "/Users/haobogu/Projects/rust/ors/ors/sample/gpt2.onnx";
-        return path;
+        path
+    }
+
+    fn setup_runtime() {
+        #[cfg(target_os = "windows")]
+        let path = "D:\\Projects\\Rust\\ors\\onnxruntime.dll";
+        #[cfg(target_os = "macos")]
+        let path = "/usr/local/lib/libonnxruntime.1.8.1.dylib";
+        #[cfg(target_os = "linux")]
+        let path = "/usr/local/lib/libonnxruntime.so";
+        initialize_runtime(Path::new(path)).unwrap();
     }
 }
