@@ -46,12 +46,26 @@ pub(crate) fn check_status(status: *mut OrtStatus) -> Result<()> {
 
 #[cfg(test)]
 mod test {
+    use std::path::Path;
+
+    use crate::api::initialize_runtime;
+
     use super::*;
 
     #[test]
     fn test_ort_status() {
+        setup_runtime();
         let status = create_status(OrtErrorCode_ORT_MODEL_LOADED, "OKOKOKO".to_string());
         assert_eq!(9, get_error_code(status));
         release_status(status as *mut OrtStatus);
     }
+    fn setup_runtime() {
+        #[cfg(target_os = "windows")]
+        let path = "D:\\Projects\\Rust\\ors\\onnxruntime.dll";
+        #[cfg(target_os = "macos")]
+        let path = "/usr/local/lib/libonnxruntime.1.8.1.dylib";
+        #[cfg(target_os = "linux")]
+        let path = "/usr/local/lib/libonnxruntime.so";
+        initialize_runtime(Path::new(path)).unwrap();
+    }
 }
